@@ -21,7 +21,20 @@ def softplus2(x):
     Returns:
          (Tensor) output tensor
     """
-    return kb.relu(x) + kb.log(0.5*kb.exp(-kb.abs(x)) + 0.5)
+    return kb.relu(x) + kb.log(0.5 * kb.exp(-kb.abs(x)) + 0.5)
+
+
+def swish(x):
+    """
+    out = x * sigmoid(x)
+
+    Args:
+        x: (Tensor) input tensor
+
+    Returns:
+        (Tensor) output tensor
+    """
+    return x * kb.sigmoid(x)
 
 
 def get(identifier: OptStrOrCallable = None) -> Callable[..., Any]:
@@ -40,4 +53,4 @@ def get(identifier: OptStrOrCallable = None) -> Callable[..., Any]:
     except ValueError:
         if isinstance(identifier, str):
             return deserialize(identifier, custom_objects=globals())
-    raise ValueError('Could not interpret:', identifier)
+    raise ValueError("Could not interpret:", identifier)
