@@ -11,12 +11,11 @@ from multiprocessing import Pool
 from typing import Dict, Union, List
 
 import numpy as np
-from pymatgen import Molecule, Element
+from pymatgen.core import Molecule, Element
 from pymatgen.analysis.local_env import NearNeighbors
 from pymatgen.io.babel import BabelMolAdaptor
 
-from megnet.data.graph import (StructureGraph, GaussianDistance,
-                               BaseGraphBatchGenerator, GraphBatchGenerator, Converter)
+from megnet.data.graph import StructureGraph, GaussianDistance, BaseGraphBatchGenerator, GraphBatchGenerator, Converter
 from megnet.utils.general import fast_label_binarize
 from .qm9 import ring_to_vector
 
@@ -31,17 +30,25 @@ except ImportError:
     Chem = None
 
 
-__date__ = '12/01/2018'
+__date__ = "12/01/2018"
 
 # List of features to use by default for each atom
-_ATOM_FEATURES = ['element', 'chirality', 'formal_charge', 'ring_sizes',
-                  'hybridization', 'donor', 'acceptor', 'aromatic']
+_ATOM_FEATURES = [
+    "element",
+    "chirality",
+    "formal_charge",
+    "ring_sizes",
+    "hybridization",
+    "donor",
+    "acceptor",
+    "aromatic",
+]
 
 # List of features to use by default for each bond
-_BOND_FEATURES = ['bond_type', 'same_ring', 'spatial_distance', 'graph_distance']
+_BOND_FEATURES = ["bond_type", "same_ring", "spatial_distance", "graph_distance"]
 
 # List of elements in library to use by default
-_ELEMENTS = ['H', 'C', 'N', 'O', 'F']
+_ELEMENTS = ["H", "C", "N", "O", "F"]
 
 
 class SimpleMolGraph(StructureGraph):
@@ -50,11 +57,13 @@ class SimpleMolGraph(StructureGraph):
     as bond features. By default the distance is expanded using a Gaussian
     expansion with centers at np.linspace(0, 4, 20) and width of 0.5
     """
-    def __init__(self,
-                 nn_strategy: Union[str, NearNeighbors] = 'AllAtomPairs',
-                 atom_converter: Converter = None,
-                 bond_converter: Converter = None,
-                 ):
+
+    def __init__(
+        self,
+        nn_strategy: Union[str, NearNeighbors] = "AllAtomPairs",
+        atom_converter: Converter = None,
+        bond_converter: Converter = None,
+    ):
         """
         Args:
             nn_strategy (str): NearNeighbor strategy
@@ -63,8 +72,7 @@ class SimpleMolGraph(StructureGraph):
         """
         if bond_converter is None:
             bond_converter = GaussianDistance(np.linspace(0, 4, 20), 0.5)
-        super().__init__(nn_strategy=nn_strategy, atom_converter=atom_converter,
-                         bond_converter=bond_converter)
+        super().__init__(nn_strategy=nn_strategy, atom_converter=atom_converter, bond_converter=bond_converter)
 
 
 class MolecularGraph(StructureGraph):
@@ -103,12 +111,15 @@ class MolecularGraph(StructureGraph):
         a vector of 20 different values computed using the `GaussianDistance` converter
 
     """
-    def __init__(self,
-                 atom_features: List[str] = None,
-                 bond_features: List[str] = None,
-                 distance_converter: Converter = None,
-                 known_elements: List[str] = None,
-                 max_ring_size: int = 9):
+
+    def __init__(
+        self,
+        atom_features: List[str] = None,
+        bond_features: List[str] = None,
+        distance_converter: Converter = None,
+        known_elements: List[str] = None,
+        max_ring_size: int = 9,
+    ):
         """
         Args:
             atom_features ([str]): List of atom features to compute
@@ -122,7 +133,7 @@ class MolecularGraph(StructureGraph):
 
         # Check if openbabel and RDKit are installed
         if Chem is None or pybel is None:
-            raise RuntimeError('RDKit and openbabel must be installed')
+            raise RuntimeError("RDKit and openbabel must be installed")
 
         super().__init__()
         if bond_features is None:
@@ -137,20 +148,17 @@ class MolecularGraph(StructureGraph):
         # Check if all feature names are valid
         if any(i not in _ATOM_FEATURES for i in atom_features):
             bad_features = set(atom_features).difference(_ATOM_FEATURES)
-            raise ValueError('Unrecognized atom features: {}'.format(', '.join(bad_features)))
+            raise ValueError("Unrecognized atom features: {}".format(", ".join(bad_features)))
         self.atom_features = atom_features
         if any(i not in _BOND_FEATURES for i in bond_features):
             bad_features = set(bond_features).difference(_BOND_FEATURES)
-            raise ValueError('Unrecognized bond features: {}'.format(', '.join(bad_features)))
+            raise ValueError("Unrecognized bond features: {}".format(", ".join(bad_features)))
         self.bond_features = bond_features
         self.known_elements = known_elements
         self.distance_converter = distance_converter
         self.max_ring_size = max_ring_size
 
-    def convert(self,
-                mol,  # type: ignore
-                state_attributes: List = None,
-                full_pair_matrix: bool = True) -> Dict:
+    def convert(self, mol, state_attributes: List = None, full_pair_matrix: bool = True) -> Dict:  # type: ignore
         """
         Compute the representation for a molecule
 
@@ -179,16 +187,15 @@ class MolecularGraph(StructureGraph):
                 continue
 
         # Compute the graph distance, if desired
-        if 'graph_distance' in self.bond_features:
+        if "graph_distance" in self.bond_features:
             graph_dist = self._dijkstra_distance(atom_pairs)
             for pair in atom_pairs:
-                d: Dict = {'graph_distance': graph_dist[pair['a_idx'], pair['b_idx']]}
+                d: Dict = {"graph_distance": graph_dist[pair["a_idx"], pair["b_idx"]]}
                 pair.update(d)
 
         # Generate the state attributes (that describe the whole network)
         state_attributes = state_attributes or [
-            [mol.molwt / num_atoms,
-             len([i for i in atom_pairs if i['bond_type'] > 0]) / num_atoms]
+            [mol.molwt / num_atoms, len([i for i in atom_pairs if i["bond_type"] > 0]) / num_atoms]
         ]
 
         # Get the atom features in the order they are requested by the user as a 2D array
@@ -202,8 +209,8 @@ class MolecularGraph(StructureGraph):
         index2_temp = []
         for bond in atom_pairs:
             # Store the index of each bond
-            index1_temp.append(bond.pop('a_idx'))
-            index2_temp.append(bond.pop('b_idx'))
+            index1_temp.append(bond.pop("a_idx"))
+            index2_temp.append(bond.pop("b_idx"))
 
             # Get the desired bond features
             bonds.append(self._create_pair_feature_vector(bond))
@@ -219,11 +226,7 @@ class MolecularGraph(StructureGraph):
         index2 = np.array(index2)[sorted_arg].tolist()
         bonds = np.array(bonds)[sorted_arg].tolist()
 
-        return {'atom': atoms,
-                'bond': bonds,
-                'state': state_attributes,
-                'index1': index1,
-                'index2': index2}
+        return {"atom": atoms, "bond": bonds, "state": state_attributes, "index1": index1, "index2": index2}
 
     def _create_pair_feature_vector(self, bond: Dict) -> List[int]:
         """Generate the feature vector from the bond feature dictionary
@@ -234,7 +237,7 @@ class MolecularGraph(StructureGraph):
             bond (dict): Features for a certain pair of atoms
         Returns:
             ([float]) Values converted to a vector
-            """
+        """
         bond_temp: List[int] = []
         for i in self.bond_features:
             # Some features require conversion (e.g., binarization)
@@ -267,15 +270,15 @@ class MolecularGraph(StructureGraph):
         """
         atom_temp = []
         for i in self.atom_features:
-            if i == 'chirality':
+            if i == "chirality":
                 atom_temp.extend(fast_label_binarize(atom[i], [0, 1, 2]))
-            elif i == 'element':
+            elif i == "element":
                 atom_temp.extend(fast_label_binarize(atom[i], self.known_elements))
-            elif i in ['aromatic', 'donor', 'acceptor']:
+            elif i in ["aromatic", "donor", "acceptor"]:
                 atom_temp.append(int(atom[i]))
-            elif i == 'hybridization':
+            elif i == "hybridization":
                 atom_temp.extend(fast_label_binarize(atom[i], [1, 2, 3, 4, 5, 6]))
-            elif i == 'ring_sizes':
+            elif i == "ring_sizes":
                 atom_temp.extend(ring_to_vector(atom[i], self.max_ring_size))
             else:  # It is a scalar
                 atom_temp.append(atom[i])
@@ -294,13 +297,13 @@ class MolecularGraph(StructureGraph):
         """
         bonds = []
         for p in pairs:
-            if p['bond_type'] > 0:
-                bonds.append([p['a_idx'], p['b_idx']])
+            if p["bond_type"] > 0:
+                bonds.append([p["a_idx"], p["b_idx"]])
         return dijkstra_distance(bonds)
 
-    def get_atom_feature(self,
-                         mol,  # type: ignore
-                         atom) -> Dict:  # type: ignore
+    def get_atom_feature(
+        self, mol, atom  # type: ignore
+    ) -> Dict:  # type: ignore
         """
         Generate all features of a particular atom
 
@@ -319,29 +322,31 @@ class MolecularGraph(StructureGraph):
         element = Element.from_Z(obatom.GetAtomicNum()).symbol
 
         # Get the fast-to-compute properties
-        output = {"element": element,
-                  "atomic_num": obatom.GetAtomicNum(),
-                  "formal_charge": obatom.GetFormalCharge(),
-                  "hybridization": 6 if element == 'H' else obatom.GetHyb(),
-                  "acceptor": obatom.IsHbondAcceptor(),
-                  "donor": obatom.IsHbondDonorH() if atom.type == 'H' else obatom.IsHbondDonor(),
-                  "aromatic": obatom.IsAromatic(),
-                  "coordid": atom.coordidx}
+        output = {
+            "element": element,
+            "atomic_num": obatom.GetAtomicNum(),
+            "formal_charge": obatom.GetFormalCharge(),
+            "hybridization": 6 if element == "H" else obatom.GetHyb(),
+            "acceptor": obatom.IsHbondAcceptor(),
+            "donor": obatom.IsHbondDonorH() if atom.type == "H" else obatom.IsHbondDonor(),
+            "aromatic": obatom.IsAromatic(),
+            "coordid": atom.coordidx,
+        }
 
         # Get the chirality, if desired
-        if 'chirality' in self.atom_features:
+        if "chirality" in self.atom_features:
             # Determine whether the molecule has chiral centers
             chiral_cc = self._get_chiral_centers(mol)
             if atom_idx not in chiral_cc:
-                output['chirality'] = 0
+                output["chirality"] = 0
             else:
                 # 1 --> 'R', 2 --> 'S'
-                output['chirality'] = 1 if chiral_cc[atom_idx] == 'R' else 2
+                output["chirality"] = 1 if chiral_cc[atom_idx] == "R" else 2
 
         # Find the rings, if desired
-        if 'ring_sizes' in self.atom_features:
+        if "ring_sizes" in self.atom_features:
             rings = mol.OBMol.GetSSSR()  # OpenBabel caches ring computation internally, no need to cache ourselves
-            output['ring_sizes'] = [r.Size() for r in rings if r.IsInRing(atom.idx)]
+            output["ring_sizes"] = [r.Size() for r in rings if r.IsInRing(atom.idx)]
         return output
 
     @staticmethod
@@ -357,14 +362,15 @@ class MolecularGraph(StructureGraph):
         a1 = mol.OBMol.GetAtom(bid + 1)
         a2 = mol.OBMol.GetAtom(eid + 1)
         same_ring = mol.OBMol.AreInSameRing(a1, a2)
-        return {"a_idx": bid,
-                "b_idx": eid,
-                "bond_type": 0,
-                "same_ring": bool(same_ring),
-                "spatial_distance": a1.GetDistance(a2)}
+        return {
+            "a_idx": bid,
+            "b_idx": eid,
+            "bond_type": 0,
+            "same_ring": bool(same_ring),
+            "spatial_distance": a1.GetDistance(a2),
+        }
 
-    def get_pair_feature(self, mol, bid: int,
-                         eid: int, full_pair_matrix: bool) -> Union[Dict, None]:
+    def get_pair_feature(self, mol, bid: int, eid: int, full_pair_matrix: bool) -> Union[Dict, None]:
         """
         Get the features for a certain bond
 
@@ -390,20 +396,22 @@ class MolecularGraph(StructureGraph):
         a1 = mol.OBMol.GetAtom(bid + 1)
         a2 = mol.OBMol.GetAtom(eid + 1)
         same_ring = mol.OBMol.AreInSameRing(a1, a2)
-        return {"a_idx": bid,
-                "b_idx": eid,
-                "bond_type": 4 if bond.IsAromatic() else bond.GetBondOrder(),
-                "same_ring": bool(same_ring),
-                "spatial_distance": a1.GetDistance(a2)}
+        return {
+            "a_idx": bid,
+            "b_idx": eid,
+            "bond_type": 4 if bond.IsAromatic() else bond.GetBondOrder(),
+            "same_ring": bool(same_ring),
+            "spatial_distance": a1.GetDistance(a2),
+        }
 
     @staticmethod
-    def _get_rdk_mol(mol, format: str = 'smiles'):
+    def _get_rdk_mol(mol, format: str = "smiles"):
         """
         Return: RDKit Mol (w/o H)
         """
-        if format == 'pdb':
+        if format == "pdb":
             return Chem.rdmolfiles.MolFromPDBBlock(mol.write("pdb"))
-        if format == 'smiles':
+        if format == "smiles":
             return Chem.rdmolfiles.MolFromSmiles(mol.write("smiles"))
         return None
 
@@ -419,7 +427,7 @@ class MolecularGraph(StructureGraph):
         Return:
             (dict): Keys are the atom index and values are the CIP label
         """
-        mol_rdk = self._get_rdk_mol(mol, 'smiles')
+        mol_rdk = self._get_rdk_mol(mol, "smiles")
         if mol_rdk is None:
             # Conversion to RDKit has failed
             return {}
@@ -456,8 +464,7 @@ def dijkstra_distance(bonds: List[List[int]]) -> np.ndarray:
             for k in np.where(graph_dist[s, :] == 1)[0]:
                 if k not in visited:
                     queue.append(k)
-                    graph_dist[i, k] = min(graph_dist[i, k],
-                                           graph_dist[i, s] + 1)
+                    graph_dist[i, k] = min(graph_dist[i, k], graph_dist[i, s] + 1)
                     graph_dist[k, i] = graph_dist[i, k]
     return graph_dist
 
@@ -471,7 +478,7 @@ def mol_from_smiles(smiles: str):
     Returns:
         openbabel molecule
     """
-    mol = pybel.readstring(format='smi', string=smiles)
+    mol = pybel.readstring(format="smi", string=smiles)
     mol.make3D()
     return mol
 
@@ -486,14 +493,13 @@ def mol_from_pymatgen(mol: Molecule):
     return mol
 
 
-def mol_from_file(file_path: str, file_format: str = 'xyz'):
+def mol_from_file(file_path: str, file_format: str = "xyz"):
     """
     Args:
         file_path(str)
         file_format(str): allow formats that open babel supports
     """
-    mol = list(pybel.readfile(
-        format=file_format, filename=file_path))[0]
+    mol = list(pybel.readfile(format=file_format, filename=file_path))[0]
     return mol
 
 
@@ -517,7 +523,7 @@ def _convert_mol(mol: str, molecule_format: str, converter: MolecularGraph) -> D
     """
 
     # Convert molecule into pybel format
-    if molecule_format == 'smiles':
+    if molecule_format == "smiles":
         mol = mol_from_smiles(mol)  # Used to generate 3D coordinates/H atoms
     else:
         mol = pybel.readstring(molecule_format, mol)
@@ -532,14 +538,16 @@ class MolecularGraphBatchGenerator(BaseGraphBatchGenerator):
     we recommend using :class:`megnet.data.graph.GraphBatchGenerator` instead to avoid
     the computational cost of dynamically computing graphs."""
 
-    def __init__(self,
-                 mols: List[str],
-                 targets: List[np.ndarray] = None,
-                 converter: MolecularGraph = None,
-                 molecule_format: str = 'xyz',
-                 batch_size: int = 128,
-                 shuffle: bool = True,
-                 n_jobs: int = 1):
+    def __init__(
+        self,
+        mols: List[str],
+        targets: List[np.ndarray] = None,
+        converter: MolecularGraph = None,
+        molecule_format: str = "xyz",
+        batch_size: int = 128,
+        shuffle: bool = True,
+        n_jobs: int = 1,
+    ):
         """
         Args:
             mols ([str]): List of the string reprensetations of each molecule
@@ -560,8 +568,9 @@ class MolecularGraphBatchGenerator(BaseGraphBatchGenerator):
         self.n_jobs = n_jobs
 
         def mute():
-            sys.stdout = open(os.devnull, 'w')
-            sys.stderr = open(os.devnull, 'w')
+            sys.stdout = open(os.devnull, "w")
+            sys.stderr = open(os.devnull, "w")
+
         self.pool = Pool(self.n_jobs, initializer=mute) if self.n_jobs != 1 else None
 
     def __del__(self):
@@ -589,8 +598,7 @@ class MolecularGraphBatchGenerator(BaseGraphBatchGenerator):
         if self.pool is None:
             graphs = [_convert_mol(m, self.molecule_format, self.converter) for m in mols]
         else:
-            func = partial(_convert_mol, molecule_format=self.molecule_format,
-                           converter=self.converter)
+            func = partial(_convert_mol, molecule_format=self.molecule_format, converter=self.converter)
             graphs = self.pool.map(func, mols)
         return graphs
 
@@ -605,13 +613,16 @@ class MolecularGraphBatchGenerator(BaseGraphBatchGenerator):
         graphs = self._generate_graphs(self.mols)
 
         # Turn them into a fat array
-        atom_features, bond_features, state_features, index1_list, index2_list, targets = \
-            self.converter.get_flat_data(graphs, self.targets)  # type: ignore
-        return GraphBatchGenerator(atom_features=atom_features,
-                                   bond_features=bond_features,
-                                   state_features=state_features,
-                                   index1_list=index1_list,
-                                   index2_list=index2_list,
-                                   targets=targets,
-                                   is_shuffle=self.is_shuffle,
-                                   batch_size=self.batch_size)
+        atom_features, bond_features, state_features, index1_list, index2_list, targets = self.converter.get_flat_data(
+            graphs, self.targets
+        )  # type: ignore
+        return GraphBatchGenerator(
+            atom_features=atom_features,
+            bond_features=bond_features,
+            state_features=state_features,
+            index1_list=index1_list,
+            index2_list=index2_list,
+            targets=targets,
+            is_shuffle=self.is_shuffle,
+            batch_size=self.batch_size,
+        )
