@@ -1,13 +1,12 @@
 import tensorflow as tf
 import unittest
-from megnet.data.graph import GaussianDistance, GraphBatchGenerator, GraphBatchDistanceConvert,\
-    EmbeddingMap
+from megnet.data.graph import GaussianDistance, GraphBatchGenerator, GraphBatchDistanceConvert, EmbeddingMap
 import numpy as np
 
 
 class TestGraph(unittest.TestCase):
     def test_gaussian_expansion(self):
-        x = np.random.normal(size=(10, ))
+        x = np.random.normal(size=(10,))
         centers = np.linspace(0, 5, 20)
         width = 0.5
         gd = GaussianDistance(centers, width)
@@ -21,8 +20,7 @@ class TestGraph(unittest.TestCase):
         index1 = [np.array([0, 1]), np.array([0])]
         index2 = [np.array([1, 2]), np.array([1])]
         targets = np.random.normal(size=(2, 1))
-        gen = GraphBatchGenerator(feature, bond, glob_features, index1, index2, targets,
-                                  batch_size=2)
+        gen = GraphBatchGenerator(feature, bond, glob_features, index1, index2, targets, batch_size=2)
         data = gen[0]
         self.assertListEqual(list(data[0][0].shape), [1, 5, 4])
         self.assertListEqual(list(data[0][1].shape), [1, 3, 5])
@@ -41,23 +39,29 @@ class TestGraph(unittest.TestCase):
         # when bonds are one dimension arrays
 
         bond = [np.random.normal(size=(2,)), np.random.normal(size=(1,))]
-        gen = GraphBatchGenerator(feature, bond, glob_features, index1, index2, targets,
-                                  batch_size=2)
+        gen = GraphBatchGenerator(feature, bond, glob_features, index1, index2, targets, batch_size=2)
         data = gen[0]
         self.assertListEqual(list(data[0][1].shape), [1, 3])
 
     def test_graph_batch_distance_converter(self):
         feature = [np.random.normal(size=(3, 4)), np.random.normal(size=(2, 4))]
-        bond = [np.random.normal(size=(2, )), np.random.normal(size=(1, ))]
-        glob_features = [np.random.normal(size=(1, 2)),
-                         np.random.normal(size=(1, 2))]
+        bond = [np.random.normal(size=(2,)), np.random.normal(size=(1,))]
+        glob_features = [np.random.normal(size=(1, 2)), np.random.normal(size=(1, 2))]
         index1 = [np.array([0, 1]), np.array([0])]
         index2 = [np.array([1, 2]), np.array([1])]
         targets = np.random.normal(size=(2, 1))
         centers = np.linspace(0, 5, 20)
         width = 0.5
-        gen = GraphBatchDistanceConvert(feature, bond, glob_features, index1, index2, targets, batch_size=2,
-                                        distance_converter=GaussianDistance(centers, width))
+        gen = GraphBatchDistanceConvert(
+            feature,
+            bond,
+            glob_features,
+            index1,
+            index2,
+            targets,
+            batch_size=2,
+            distance_converter=GaussianDistance(centers, width),
+        )
         data = gen[0]
         self.assertListEqual(list(data[0][0].shape), [1, 5, 4])
         self.assertListEqual(list(data[0][1].shape), [1, 3, 20])
