@@ -1,11 +1,15 @@
 import tensorflow as tf
 import unittest
-from megnet.activations import softplus2
+from megnet.activations import softplus2, swish
 import numpy as np
 
 
 def softplus_np(x):
-    return np.log(np.exp(x) + 1) - np.log(2.)
+    return np.log(np.exp(x) + 1) - np.log(2.0)
+
+
+def swish_np(x):
+    return x / (1 + np.exp(-x))
 
 
 class TestSP(unittest.TestCase):
@@ -13,6 +17,10 @@ class TestSP(unittest.TestCase):
         x = 10.0
         self.assertAlmostEqual(softplus2(x).numpy(), softplus_np(x), places=5)
 
+    def test_swish(self):
 
-if __name__ == '__main__':
+        self.assertAlmostEqual(swish(10.0).numpy(), swish_np(10.0), places=5)
+
+
+if __name__ == "__main__":
     unittest.main()
